@@ -1,31 +1,35 @@
 package WWW::Marvel;
 use strict;
 use warnings;
+use base qw/ Class::Accessor /;
+__PACKAGE__->follow_best_practice;
+__PACKAGE__->mk_accessors(qw/ public_key private_key /);
 
-our $VERSION = '0.04';
+our $VERSION = '0.01';
 
 =head1 NAME
 
 WWW::Marvel - A Marvel Comics API
 
+
 =head1 VERSION
 
-Version 0.04
+Version 0.01
 
 
 =head1 SYNOPSIS
 
-  use WWW::Marvel::Config;
+  use WWW::Marvel;
+
+  my $api = WWW::Marvel->new({ public_key => 1234, private_key => 'abcd' });
+
+  ###
+
   use WWW::Marvel::Client;
 
-  my $cfg = WWW::Marvel::Config::File->new("my_marvel.conf");
-
-  my $client = WWW::Marvel::Client->new({
-    public_key  => $cfg->get_public_key,
-	private_key => $cfg->get_private_key
-  });
-
-  my $data = $client->characters({ name => 'spider-man' });
+  my $client = WWW::Marvel::Client->new({ public_key => 1234, private_key => 'abcd' });
+  $client->set_timestamp(1431297266);
+  $client->hash();
 
 
 =head1 DESCRIPTION
